@@ -1,7 +1,9 @@
 """Create system tray and its menu."""
+import datetime
 import io
 import logging
 import os
+import sys
 import tempfile
 import time
 from functools import partial
@@ -9,14 +11,14 @@ from functools import partial
 from PIL import Image
 from PySide6 import QtCore, QtGui, QtWidgets
 
-from normcap import clipboard, ocr
+from normcap import __version__, clipboard, ocr, screengrab
 from normcap.gui import system_info, utils
+from normcap.gui.constants import UPDATE_CHECK_INTERVAL_DAYS
 from normcap.gui.models import Capture, CaptureMode, DesktopEnvironment, Rect, Screen
 from normcap.gui.notifier import Notifier
 from normcap.gui.settings import Settings
 from normcap.gui.update_check import UpdateChecker
 from normcap.gui.window import Window
-from normcap.screengrab import grab_screens
 
 logger = logging.getLogger(__name__)
 
@@ -24,18 +26,16 @@ logger = logging.getLogger(__name__)
 class Communicate(QtCore.QObject):
     """TrayMenus' communication bus."""
 
-    on_tray_menu_capture = QtCore.Signal()
+    on_tray_menu_capture_clicked = QtCore.Signal()
     on_quit = QtCore.Signal()
     on_ocr_performed = QtCore.Signal()
     on_copied_to_clipboard = QtCore.Signal()
     on_send_notification = QtCore.Signal(Capture)
     on_window_positioned = QtCore.Signal()
     on_open_url_and_hide = QtCore.Signal(str)
-    on_set_cursor_wait = QtCore.Signal()
     on_close_or_exit = QtCore.Signal(str)
     on_region_selected = QtCore.Signal(Rect)
     on_image_cropped = QtCore.Signal()
-    on_minimize_windows = QtCore.Signal()
     on_screenshots_updated = QtCore.Signal()
 
 
@@ -65,11 +65,43 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
 
         self._set_tray_icon()
         self._add_tray_menu()
+        self._ensure_screenshot_permission()
         self._add_update_checker()
         self._add_notifier()
         self._set_signals()
         self._update_screenshots()
 
+    def _ensure_screenshot_permission(self):
+        if screengrab.has_screenshot_permission():
+            return
+
+        if sys.platform == "darwin":
+            # Reset privacy permission in case of new NormCap version. This is necessary
+            # because somehow the setting is associated with the binary and won't work
+            # after it got updated.
+            if self.settings.value("version") != __version__:
+                self.settings.setValue("version", __version__)
+                screengrab.macos_reset_screenshot_permission()
+
+            # Trigger permission request to make the NormCap entry available in settings
+            screengrab.macos_request_screenshot_permission()
+
+            # Message box to explain what's happening and open the preferences
+            app = "NormCap" if system_info.is_prebuild_package() else "Terminal"
+            button = QtWidgets.QMessageBox.critical(
+                None,
+                "Error!",
+                f"{app} is missing permissions for 'Screen Recording'.\n\n"
+                + "Grant the permissions via 'Privacy & Security' settings "
+                + "and restart NormCap.\n\nClick OK to exit.",
+                buttons=QtWidgets.QMessageBox.Open | QtWidgets.QMessageBox.Cancel,
+            )
+            if button == QtWidgets.QMessageBox.Open:
+                logger.debug("Open macOS privacy settings")
+                screengrab.macos_open_privacy_settings()
+
+            self._exit_application("Screen Recording permissions missing on macOS")
+
     def _set_tray_icon(self):
         self.setIcon(utils.get_icon("tray.png", "tool-magic-symbolic"))
 
@@ -87,7 +119,7 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
 
     def _set_signals(self):
         """Set up signals to trigger program logic."""
-        self.com.on_tray_menu_capture.connect(self._delayed_update_screenshots)
+        self.com.on_tray_menu_capture_clicked.connect(self._delayed_update_screenshots)
         self.com.on_screenshots_updated.connect(self._show_windows)
         self.com.on_quit.connect(lambda: self._exit_application("clicked exit in tray"))
         self.com.on_region_selected.connect(self._close_windows)
@@ -97,19 +129,27 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
         self.com.on_copied_to_clipboard.connect(self._notify_or_close)
         self.com.on_copied_to_clipboard.connect(self._color_tray_icon)
 
-        self.com.on_minimize_windows.connect(self._close_windows)
-        self.com.on_set_cursor_wait.connect(
-            lambda: utils.set_cursor(QtCore.Qt.WaitCursor)
-        )
         self.com.on_close_or_exit.connect(self._close_or_exit)
         self.com.on_open_url_and_hide.connect(self._open_url_and_hide)
 
     def _add_update_checker(self):
-        if self.settings.value("update", type=bool):
-            checker = UpdateChecker(self, packaged=system_info.is_prebuild_package())
-            checker.com.on_version_retrieved.connect(checker.show_update_message)
-            checker.com.on_click_get_new_version.connect(self.com.on_open_url_and_hide)
-            QtCore.QTimer.singleShot(500, checker.check)
+        if self.settings.value("update", type=bool) is False:
+            return
+
+        interval = datetime.timedelta(days=UPDATE_CHECK_INTERVAL_DAYS)
+        today_minus_interval = f"{datetime.datetime.now() - interval:%Y-%m-%d}"
+        if self.settings.value("last-update-check", type=str) > today_minus_interval:
+            return
+
+        checker = UpdateChecker(self, packaged=system_info.is_prebuild_package())
+        checker.com.on_version_parsed.connect(self._update_time_of_last_update_check)
+        checker.com.on_click_get_new_version.connect(self.com.on_open_url_and_hide)
+        QtCore.QTimer.singleShot(500, checker.check)
+
+    def _update_time_of_last_update_check(self, newest_version):
+        if newest_version is not None:
+            today = f"{datetime.datetime.now():%Y-%m-%d}"
+            self.settings.setValue("last-update-check", today)
 
     def _add_notifier(self):
         self.notifier = Notifier(self)
@@ -120,7 +160,7 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
 
     def _update_screenshots(self):
         """Get new screenshots and cache them."""
-        screens = grab_screens()
+        screens = screengrab.capture()
 
         if not screens:
             logger.error("Could not grab screenshots.")
@@ -145,7 +185,7 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
         menu = QtWidgets.QMenu()
 
         action = QtGui.QAction("Capture", menu)
-        action.triggered.connect(self.com.on_tray_menu_capture.emit)
+        action.triggered.connect(self.com.on_tray_menu_capture_clicked.emit)
         menu.addAction(action)
 
         action = QtGui.QAction("Exit", menu)
@@ -292,4 +332,6 @@ class SystemTray(QtWidgets.QSystemTrayIcon):
         time.sleep(0.05)
         logger.debug("Path to debug images: %s%snormcap", tempfile.gettempdir(), os.sep)
         logger.info("Exit normcap (reason: %s)", reason)
-        QtWidgets.QApplication.quit()
+        # The preferable QApplication.quit() doesn't work reliably on macOS. E.g. when
+        # right clicking on "close" in tray menu, NormCap process keeps running.
+        sys.exit(0)
