@@ -7,7 +7,7 @@ from PySide6 import QtGui, QtWidgets
 logger = logging.getLogger(__name__)
 
 
-def grab_screens() -> list[QtGui.QImage]:
+def capture() -> list[QtGui.QImage]:
     """Capture screenshot with QT method and Screen object.
 
     Works well on X11, fails on multi monitor macOS.
